==> msmtp-scripts-1.2.4.tar.gz: msmtp-scripts-1.2.4/tests/scripts/t30200-test-localhost-mta.sh <==
#!/bin/sh
#
# msmtp-scripts test framework
#
#    Copyright (C) 2019 Daniel F. Dickinson <cshored@thecshore.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

OTS=SUCCESS
TS=PASS

rm -rf ./tmp/msmtp.queue.log
rm -rf ./tmp/msmtp.queue

sudo cp /etc/msmtprc /etc/msmtprc.test.old
sudo cp $(pwd)/.msmtprc /etc/msmtprc

export MSMTP_MTA_SKIP_CONF=true
export MSMTP_MTA_OVERRIDE_CONF=./tmp/msmtpq-ng-real.rc

echo "Subject: queuing mail

no host"| /usr/sbin/msmtpq-ng-mta root
RC=$?

if [ "$RC" != "75" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Sendmail to root fails (TEMPFAIL due to no host)"

TS=PASS

if ! sudo journalctl -t msmtpq-ng | grep -qiE 'enqueued.*as.*( root )'; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Sendmail queued mail"

TS=PASS

sudo rm -rf /var/spool/msmtp/msmtp/*
sudo chown "$USER":"$(id -gn "$USER")" $(pwd)/tmp/dot_msmtprc

if ! echo "To: root@localhost
From: $USER@localhost
Subject: test localhost listener

Test localhost listener"| msmtp -C $(pwd)/tmp/dot_msmtprc root@localhost; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtp to localhost succeeded"

TS=PASS

if ! sudo grep -rq 'Test localhost listener' /var/spool/msmtp/msmtp; then
	TS=FAIL
	OTS=FAIL
fi

sudo rm -f /etc/msmtprc
sudo cp /etc/msmtprc.test.old /etc/msmtprc
sudo chmod 600 /etc/msmtprc
sudo chown root:root /etc/msmtprc

echo "$TS: msmtp to localhost queued mail"

if [ "$OTS" = "FAIL" ]; then
	exit 3
else
	exit 0
fi

==> msmtp-scripts-1.2.5.1.tar.gz: msmtp-scripts-1.2.5.1/tests/scripts/t30200-test-localhost-mta.sh <==
#!/bin/sh
#
# msmtp-scripts test framework
#
#    Copyright (C) 2019 Daniel F. Dickinson <cshored@thecshore.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

OTS=SUCCESS

rm -rf ./tmp/msmtp.queue.log
rm -rf ./tmp/msmtp.queue

sudo cp /etc/msmtprc /etc/msmtprc.test.old
sudo cp "$(pwd)"/tmp/.msmtprc /etc/msmtprc

export MSMTP_MTA_SKIP_CONF=true
export MSMTP_MTA_OVERRIDE_CONF=./tmp/msmtpq-ng-real.rc

TS=PASS

echo "Subject: queuing mail

queue first"| MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}18-1 /usr/sbin/msmtpq-ng-mta -kcov "${KCOV_BASE}18-1" root

sudo journalctl -t msmtpq-ng | grep -qi 'msmtpq set to queue first' 

RC=$?

if [ "$RC" != "0" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Sendmail to root queues rather than sends" 

sed -i -e '$a\MSMTP_QUEUE_FIRST=false' ./tmp/msmtpq-ng-real.rc

TS=PASS

echo "Subject: queuing mail

no host"| MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}18-2 /usr/sbin/msmtpq-ng-mta -kcov "${KCOV_BASE}18-2" root
RC=$?

if [ "$RC" != "75" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Sendmail to root fails (TEMPFAIL due to no host)"

TS=PASS

if ! sudo journalctl -t msmtpq-ng | grep -qiE 'enqueued.*as.*( root )'; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Sendmail queued mail"

sed -i -e '/MSMTP_QUEUE_FIRST=false/d' ./tmp/msmtpq-ng-real.rc

TS=PASS

sudo rm -rf /var/spool/msmtp/msmtp/*
sudo chown "$USER":"$(id -gn "$USER")" "$(pwd)"/tmp/dot_msmtprc

if ! echo "To: root@localhost
From: $USER@localhost
Subject: test localhost listener

Test localhost listener"| msmtp -C $(pwd)/tmp/dot_msmtprc root@localhost; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: msmtp to localhost succeeded"

TS=PASS

if ! sudo grep -rq 'Test localhost listener' /var/spool/msmtp/msmtp; then
	TS=FAIL
	OTS=FAIL
fi

sudo rm -f /etc/msmtprc
sudo cp /etc/msmtprc.test.old /etc/msmtprc
sudo chmod 600 /etc/msmtprc
sudo chown root:root /etc/msmtprc

echo "$TS: msmtp to localhost queued mail"

if [ "$OTS" = "FAIL" ]; then
	exit 3
else
	exit 0
fi
